@@ -1,5 +1,5 @@
 /*
- * $Id: cap_proc.c,v 1.3 1997/05/04 05:35:46 morgan Exp $
+ * $Id: cap_proc.c,v 1.4 1997/05/14 05:17:13 morgan Exp $
  *
  * Copyright (c) 1997 Andrew G Morgan <morgan@parc.power.net>
  *
@@ -32,24 +32,23 @@ cap_t cap_get_proc(void)
 
 int cap_set_proc(cap_t cap_d)
 {
-    if (good_cap_t(cap_d)) {
-	_cap_debug("setting current process' capabilities");
-
-	/* fill the capability sets via a system call */
-	if (_setproccap(sizeof(struct __cap_s),
-			&cap_d->set[CAP_INHERITABLE],
-			&cap_d->set[CAP_PERMITTED],
-			&cap_d->set[CAP_EFFECTIVE] )) {
-	    _cap_debug("failed: %s", strerror(errno));
-	}
-    } else
+    if (!good_cap_t(cap_d)) {
 	errno = EINVAL;
+	return -1;
+    }
 
-    return (errno ? -1:0);
+    _cap_debug("setting process capabilities");
+    return _setproccap(sizeof(struct __cap_s),
+			  &cap_d->set[CAP_INHERITABLE],
+			  &cap_d->set[CAP_PERMITTED],
+			  &cap_d->set[CAP_EFFECTIVE] );
 }
 
 /*
  * $Log: cap_proc.c,v $
+ * Revision 1.4  1997/05/14 05:17:13  morgan
+ * bug-fix from zefram (errno no set on success)
+ *
  * Revision 1.3  1997/05/04 05:35:46  morgan
  * fixed errno setting. syscalls do this part
  *
